*FROM: http://www.ats.ucla.edu/stat/sas/dae/ologit.htm;
* Generic session options - set page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';											
* Kill default titles on output; 
TITLE;

* Location for files to be saved - CHANGE PATH;
%LET lecture8= C:\Documents and Settings\lesa\My Documents\Dropbox\!PSYC 943\Lectures\08 Examples Binary Ordinal Outcomes; 
LIBNAME lecture8 "&lecture8.";

* Import data and center/recode predictors;
DATA work.gradplan; SET lecture8.ologit;
	parentGD = pared;
	GPA3 = GPA-3;
	IF public=1 THEN private=0; ELSE private=1;
	LABEL apply=	"apply: 0=Not, 1=Eh, 2=Very"
		  parentGD= "parentGD: Parent Has Graduate Degree (0=N,1=Y)"
		  private= 	"private: Student Attends Private University (0=N,1=Y)"
		  GPA3= 	"GPA3: Student GPA (0=3)";  
RUN;

TITLE1 "DESCRIPTIVES FOR STUDY VARIABLES";
PROC MEANS DATA=work.gradplan; VAR GPA; RUN;
PROC FREQ DATA=work.gradplan; TABLE Apply parentGD private; RUN; TITLE1;

***** ORDINAL MODELS;

TITLE1 "EMPTY MODEL PREDICTING ORDINAL APPLICATION STATUS";
PROC LOGISTIC DATA=work.gradplan DESCENDING; 
* Predicting 3-category apply UP via DESCENDING option;
  MODEL apply = / ITPRINT LINK=CLOGIT;
* Requesting logit intercept to be transformed into probability (add EXP for odds, too);
  ESTIMATE "Intercept" intercept 1 / ILINK CATEGORY=SEPARATE;
RUN;

ODS GRAPHICS ON;
TITLE1 "CONDITIONAL MODEL PREDICTING ORDINAL APPLICATION STATUS";
TITLE2 "MAIN EFFECTS ONLY";
PROC LOGISTIC DATA=work.gradplan DESCENDING; 
MODEL apply = gpa3 parentGD private / LINK=CLOGIT ITPRINT RSQUARE;
* Plot to demonstrate proportional odds (use LINK to get logit, ILINK to get probability);
 * CLM=confidence limits, NOOBS=don't print people, AT is for covariate values;
  EFFECTPLOT FIT(X=GPA3) / AT (parentGD=0 private=0) ILINK CLM NOOBS; 
* Requesting conditional group means;
  ESTIMATE "Mean for No Grad Parent"   intercept 1 parentGD 0 / ILINK CATEGORY=SEPARATE;
  ESTIMATE "Mean for Yes Grad Parent"  intercept 1 parentGD 1 / ILINK CATEGORY=SEPARATE;
  ESTIMATE "Mean for Public School"    intercept 1 private  0 / ILINK CATEGORY=SEPARATE;
  ESTIMATE "Mean for Private School"   intercept 1 private  1 / ILINK CATEGORY=SEPARATE;
* Example of custom hypothesis test;
  ESTIMATE "Difference of Parent and School Effects" parentGD -1 private 1 / CATEGORY=SEPARATE;
RUN; ODS GRAPHICS OFF;

ODS GRAPHICS ON;
TITLE2 "ADDING INTERACTION OF PARENT GRAD BY SCHOOL TYPE";
PROC LOGISTIC DATA=work.gradplan DESCENDING; 
* Need to list grouping predictors on CLASS statement to get plots;
  CLASS parentGD(REF='0') private (REF='0');
* Model now includes interactions via |;
  MODEL apply = gpa3 parentGD|private / LINK=CLOGIT ITPRINT RSQUARE;
* Requesting conditional group means;
ESTIMATE "Mean for No Grad,  Public School"   intercept 1 parentGD 0 private 0 parentGD*private 0 / ILINK CATEGORY=SEPARATE;
ESTIMATE "Mean for No Grad,  Private School"  intercept 1 parentGD 0 private 1 parentGD*private 0 / ILINK CATEGORY=SEPARATE;
ESTIMATE "Mean for Yes Grad, Public School"   intercept 1 parentGD 1 private 0 parentGD*private 0 / ILINK CATEGORY=SEPARATE;
ESTIMATE "Mean for Yes Grad, Private School"  intercept 1 parentGD 1 private 1 parentGD*private 1 / ILINK CATEGORY=SEPARATE;
* Requesting simple effects per cell;
ESTIMATE "Parent Effect for Public"		parentGD 1 parentGD*private 0 / CATEGORY=SEPARATE;
ESTIMATE "Parent Effect for Private"	parentGD 1 parentGD*private 1 / CATEGORY=SEPARATE;
ESTIMATE "School Effect for No Grad"	private  1 parentGD*private 0 / CATEGORY=SEPARATE;
ESTIMATE "School Effect for No Grad"	private  1 parentGD*private 1 / CATEGORY=SEPARATE;
* Plot to demonstrate interactions (use LINK to get logit, ILINK to get probability);
* CLM=confidence limits, NOOBS=don't print people, AT is for covariate values;
EFFECTPLOT INTERACTION(X=parentGD PLOTBY=private) / AT (GPA3=0) LINK CLM NOOBS;
RUN; ODS GRAPHICS OFF;


***** NOMINAL MODELS;

TITLE1 "EMPTY MODEL PREDICTING NOMINAL APPLICATION STATUS";
TITLE2 "1 AS REFERENCE GROUP, SO PREDICTING 1 VS 0, 1 VS 2";
PROC LOGISTIC DATA=work.gradplan;  
  MODEL apply (REF='1')= / ITPRINT LINK=GLOGIT;
  * Requesting logit intercept to be transformed into probability (add EXP for odds, too);
  ESTIMATE "Intercept" intercept 1 / ILINK CATEGORY=SEPARATE;
RUN;

ODS GRAPHICS ON;
TITLE1 "CONDITIONAL MODEL PREDICTING NOMINAL APPLICATION STATUS";
TITLE2 "MAIN EFFECTS ONLY";
PROC LOGISTIC DATA=work.gradplan; 
MODEL apply (REF='1') = gpa3 parentGD private / LINK=GLOGIT ITPRINT RSQUARE;
* Test proortional odds assumption per slope;
  GPA3:		TEST -GPA3_0     = GPA3_2;
  parentGD:	TEST -parentGD_0 = parentGD_2;
  private:	TEST -private_0  = private_2;
 * Plot to demonstrate non-proportional odds (use LINK to get logit, ILINK to get probability);
 * CLM=confidence limits, NOOBS=don't print people;
  EFFECTPLOT FIT(X=parentGD) / AT (private=0 GPA3=0) ILINK CLM NOOBS;
* Requesting group means;
  ESTIMATE "Mean for No Grad Parent"   intercept 1 parentGD 0 / ILINK CATEGORY=SEPARATE;
  ESTIMATE "Mean for Yes Grad Parent"  intercept 1 parentGD 1 / ILINK CATEGORY=SEPARATE;
  ESTIMATE "Mean for Public School"    intercept 1 private  0 / ILINK CATEGORY=SEPARATE;
  ESTIMATE "Mean for Private School"   intercept 1 private  1 / ILINK CATEGORY=SEPARATE;
* Example of custom hypothesis test;
  ESTIMATE "Difference of Parent and School Effects" parentGD -1 private 1 / CATEGORY=SEPARATE;
RUN;
ODS GRAPHICS OFF;
